#!/bin/bash

# GET SUDO privilege (Change sudo to gksu or gksudo if you prefer a graphical prompt)
echo "***********************************************"
echo "*       MIDI EXPRESSION Control Setup         *"
echo "***********************************************"
echo
echo "This installer requires root privileges..."
[ "$UID" -eq 0 ] || exec sudo bash "$0" "$@"

#install dependencies
sudo apt-get install libxcb-cursor-dev libusb-dev

APP_INSTALL_FOLDER="/opt/MIDI_Expression"
BINARY_NAME="midiExpression"
VST3_NAME="midiExpression.vst3"
SHORTCUT_NAME="MIDI Expression.desktop"
USER_HOME=$(getent passwd $SUDO_USER | cut -d: -f6)
SHORTCUT_PATH="/usr/share/applications/${SHORTCUT_NAME}"
RULES_PATH="/etc/udev/rules.d/midiExpression.rules"
PDF="MIDIExpression.pdf"
ICON_NAME="icon.png"

AF_SETTINGS_PATH="${USER_HOME}/.AudioFront"
SETTINGS_PATH="${AF_SETTINGS_PATH}/MIDI_EXPRESSION"
ICON_PATH="${SETTINGS_PATH}/${ICON_NAME}"

#REMOVE OLD STUFF
if [ -d "${APP_INSTALL_FOLDER}" ]; then 
    echo "Uninstalling previous version..."
    rm -r "${APP_INSTALL_FOLDER}"
fi

#create application folder
mkdir -p "${APP_INSTALL_FOLDER}"

echo "Creating folder structure..."
#make firmware folder
mkdir "${APP_INSTALL_FOLDER}/firmware"
mkdir "${APP_INSTALL_FOLDER}/vst3"

#copy the binary
echo "Copying application binaries..."
cp "./bin/${BINARY_NAME}"  "${APP_INSTALL_FOLDER}"
cp -r "./bin/${VST3_NAME}" "${APP_INSTALL_FOLDER}/vst3/"

#copy the firmware
echo "Copying firmware..."
cp -r "./firmware" "${APP_INSTALL_FOLDER}/"


echo "Creating Desktop shortcut..."
echo "[Desktop Entry]" > "${SHORTCUT_PATH}"
echo "Type=Application" >> "${SHORTCUT_PATH}"
echo "Terminal=false" >> "${SHORTCUT_PATH}"
echo "Name=MIDI Expression" >> "${SHORTCUT_PATH}"
echo "Icon=${ICON_PATH}" >> "${SHORTCUT_PATH}"
echo "Exec=${APP_INSTALL_FOLDER}/${BINARY_NAME}" >> "${SHORTCUT_PATH}"
echo "StartupNotify=true" >> "${SHORTCUT_PATH}"
echo "StartupWMClass=MIDI Expression" >> "${SHORTCUT_PATH}"

chmod 755 "${SHORTCUT_PATH}"
chmod +x "${SHORTCUT_PATH}"


chmod -R 777 "${APP_INSTALL_FOLDER}/firmware"


echo "Adding udev rules..."

if test -f "$RULES_PATH"; then
    rm "${RULES_PATH}"
fi

touch ${RULES_PATH}

echo "# MIDI EXPRESSION rules to allow accessing to rawhid devices"  >> "${RULES_PATH}"
echo "SUBSYSTEMS==\"usb\", ATTRS{idVendor}==\"16c0\", ATTRS{idProduct}==\"0470\", MODE:=\"0666\"" >> "${RULES_PATH}"
echo "SUBSYSTEMS==\"usb\", ATTRS{idVendor}==\"16c0\", ATTRS{idProduct}==\"0471\", MODE:=\"0666\"" >> "${RULES_PATH}"
echo "SUBSYSTEMS==\"usb\", ATTRS{idVendor}==\"16c0\", ATTRS{idProduct}==\"0472\", MODE:=\"0666\"" >> "${RULES_PATH}"
echo "SUBSYSTEMS==\"usb\", ATTRS{idVendor}==\"16c0\", ATTRS{idProduct}==\"0473\", MODE:=\"0666\"" >> "${RULES_PATH}"
echo "SUBSYSTEMS==\"usb\", ATTRS{idVendor}==\"16c0\", ATTRS{idProduct}==\"0474\", MODE:=\"0666\"" >> "${RULES_PATH}"
echo "SUBSYSTEMS==\"usb\", ATTRS{idVendor}==\"16c0\", ATTRS{idProduct}==\"0475\", MODE:=\"0666\"" >> "${RULES_PATH}"
echo "SUBSYSTEMS==\"usb\", ATTRS{idVendor}==\"16c0\", ATTRS{idProduct}==\"0478\", MODE:=\"0666\"" >> "${RULES_PATH}"

udevadm control --reload

#MAKE AUDIOFRONT FOLDER IF IT DOESN'T ALREADY EXIST
if [ -d "${AF_SETTINGS_PATH}" ]; then 
    echo "AudioFront Folder found..."
else
    echo "Creating AudioFront folder..."
    mkdir "${AF_SETTINGS_PATH}"
    chmod 777 "${AF_SETTINGS_PATH}"
fi

#MAKE THE APPLICATION SETTINGS PATH
if [ -d "${SETTINGS_PATH}" ]; then 
    echo "Application settings folder found..."
else
    echo "Creating application settings folder..."
    mkdir "${SETTINGS_PATH}"
    chmod 777 "${SETTINGS_PATH}"
fi

if test -f "${USER_HOME}/.AudioFront/${PDF}"; then
    rm "${USER_HOME}/.AudioFront/${PDF}"
fi
cp "./${PDF}" "${USER_HOME}/.AudioFront/"
chmod 777 "${USER_HOME}/.AudioFront/${PDF}"

cp "./${ICON_NAME}" "${SETTINGS_PATH}"
chown $SUDO_USER "${ICON_PATH}"
chown :$SUDO_USER "${ICON_PATH}"

chmod 777 "${ICON_PATH}"


echo "Installation complete."

